==> deepin-font-manager_5.8.0.13.orig.tar.xz: deepin-font-manager-5.8.0.13/translations/deepin-font-manager_ms.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ms" version="2.1">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>Semua Fon</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistem</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Pengguna</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Kegemaran</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktif</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Bahasa Cina</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Monospace</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Sahkan</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>Fail rosak</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Versi serupa telah dipasang</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Fon Sistem</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Ctrl+Shift+K</source>
        <translation>Ctrl+Shift+K</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation>Alt+Return</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation>Fon</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>Fon %1 telah dipasang</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>Fon %1 telah dipasang</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>Are you sure you want to delete this font?</source>
        <translation>Anda pasti mahu memadam fon ini?</translation>
    </message>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Fon ini tidak tersedia untuk kegunaan aplikasi</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Fon-fon ini tidak tersedia untuk kegunaan aplikasi</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete</source>
        <translation>Padam</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>Memadam fon, tunggu sebentar...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Pengesahan Fon</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Keluar</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Teruskan</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>Tiada fon dipasang</translation>
    </message>
</context>
<context>
    <name>Font</name>
    <message>
        <source>Don&apos;t let your dreams be dreams</source>
        <translation>Jangan biarkan impian anda kekal sebagai mimpi</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Maklumat asas</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Gaya</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Jenis</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versi</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Keterangan</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Tidak diketahui</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Nama penuh</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Nama Ps</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Tanda Dagangan</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Pengurus Fon</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>Pengurus Fon membantu pengguna pasang dan urus fon-fon.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>Memuatkan fon, tunggu sebentar...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>Fon telah dieksport ke dalam atas meja anda</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1 fon telah dieksport ke dalam atas meja anda</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Tambah fon</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Benarkan</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Lumpuhkan</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Padam</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Kegemaran</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Nyahgemar</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Perincian</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Papar dalam pengurus fail</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Eksport</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>dinyahaktif</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>Fon telah dinyahaktifkan</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Some fonts are not allowed to be disabled</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Pasang Fon</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>Mengesahkan...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Tidak diketahui</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>Fail rosak</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Dipasang</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>Tidak Dipasang</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Pasang Fon</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Gelintar</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>Tiada keputusan gelintar</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>Tiada fon</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Bantuan</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Papar pintasan</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Halaman ke atas</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Halaman ke bawah</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Padam</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Tambah fon</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Kegemaran</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Nyahgemar</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Maklumat fon</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Masukkan teks pratonton</translation>
    </message>
</context>
<context>
    <name>DFontWidget</name>
    <message>
        <source>Broken file</source>
        <translation>Fail rosak</translation>
    </message>
</context>
</TS>

==> deepin-font-manager_5.9.14.orig.tar.xz: deepin-font-manager-5.9.14/translations/deepin-font-manager_ms.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ms">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>Semua Fon</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistem</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Pengguna</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Kegemaran</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktif</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Bahasa Cina</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Monospace</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Batal</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation>%1 ialah sebuah keluarga fon, jika anda teruskan, semua fon di dalamnya akan terpadam</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Padam</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation>%1 ialah sebuah keluarga fon, jika anda teruskan, semua fon di dalamnya akan dibenarkan</translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation>%1 ialah sebuah keluarga fon, jika anda teruskan, semua fon di dalamnya akan dilumpuhkan</translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>Benarkan</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>Lumpuhkan</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation>Terap kepada semua keluarga fon terpilih</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>Fail rosak</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Versi serupa telah dipasang</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Fon Sistem</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>Fon %1 telah dipasang</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>Fon %1 telah dipasang</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation>Alt+M</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation>CTRL+I</translation>
    </message>
    <message>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Fon ini tidak tersedia untuk kegunaan aplikasi</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Fon-fon ini tidak tersedia untuk kegunaan aplikasi</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>%1 fon sistem yang lain tidak dapat dipadamkan</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>Fon &quot;%1&quot; yang masih digunakan tidak boleh dipadamkan</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>%1 fon sistem yang lain dan fon &quot;%2&quot; yang masih digunakan tidak dapat dipadamkan</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>Anda pasti mahu memadam %1 fon?</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Padam</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>Memadam fon, tunggu sebentar...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Pengesahan Fon</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>Tiada fon dipasang</translation>
    </message>
    <message>
        <source>Exit</source>
        <comment>button</comment>
        <translation>Keluar</translation>
    </message>
    <message>
        <source>Continue</source>
        <comment>button</comment>
        <translation>Teruskan</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Maklumat asas</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Gaya</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Jenis</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versi</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Keterangan</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Tidak diketahui</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Nama penuh</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Nama Ps</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Tanda Dagangan</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Pengurus Fon</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>Pengurus Fon membantu pengguna pasang dan urus fon-fon.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>Memuatkan fon, tunggu sebentar...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>Fon telah dieksport ke dalam atas meja anda</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1 fon telah dieksport ke dalam atas meja anda</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>Gagal mengeksport 1 fon. Ruang cakera tidak mencukupi.</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>Gagal mengeksport %1 fon. Ruang cakera tidak mencukupi.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Tambah fon</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Benarkan</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Lumpuhkan</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Padam</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Kegemaran</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Nyahgemar</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Perincian</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Papar dalam pengurus fail</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Eksport</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>dinyahaktif</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>Fon telah dinyahaktifkan</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1 masih digunakan, jadi anda tidak boleh melumpuhkannya</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>Anda tidak boleh melumpuhkan fon sistem dan fon yang masih digunakan</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>Anda tidak boleh melumpuhkan fon sistem</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Pasang Fon</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>Mengesahkan...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Tidak diketahui</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>Fail rosak</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Dipasang</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>Tidak Dipasang</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Pasang Fon</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Gelintar</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>Tiada keputusan gelintar</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>Tiada fon</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Bantuan</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Papar pintasan</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Halaman ke atas</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Halaman ke bawah</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Padam</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Tambah fon</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Gemar</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Nyahgemar</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Maklumat fon</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Masukkan teks pratonton</translation>
    </message>
</context>
</TS>
